@@ -2,7 +2,7 @@
 
 __docformat__ = "restructuredtext en"
 
-from cubicweb.selectors import is_instance
+from cubicweb.predicates import is_instance
 from cubicweb.server import hook
 
 WORKORDER_FINAL_STATES = set( (u'done',) )
